@@ -20,9 +20,13 @@ import re
 import requests
 import subprocess
 import sys
+import urlparse
+import yaml
 
 
 HTTP_DOWNLOAD_TIMEOUT = 15
+DEFAULT_ARTIFACTS_URL = "https://archive.validation.linaro.org/artifacts/"
+DEFAULT_ARTIFACTS_UPLOAD_PATH = "team/lava/"
 
 
 def devicedictionary_to_jinja2(data_dict, extends):
@@ -93,3 +97,49 @@ def validate_urls(definition):
                 print >> sys.stderr, "Warning: '%s' timed out" % (url[0])
             except requests.RequestException as exc:
                 print >> sys.stderr, "Warning: %s" % exc
+
+
+def publish_artifacts(definition, artifacts_url=DEFAULT_ARTIFACTS_URL,
+                      artifacts_upload_path=DEFAULT_ARTIFACTS_UPLOAD_PATH):
+
+    data = yaml.safe_load(definition)
+    # Check job definition for relevant data.
+    if 'secrets' not in data:
+        print >> sys.stderr, "Warning: Job definition is missing 'secrets' section. Artifacts will not be published."
+        return
+    if 'API_KEY' not in data["secrets"]:
+        print >> sys.stderr, "Warning: Job definition 'secrets' section is missing 'API_KEY'. Artifacts will not be published."
+        return
+    if 'API_USER' not in data["secrets"]:
+        print >> sys.stderr, "Warning: Job definition 'secrets' section is missing 'API_USER'. Artifacts will not be published."
+        return
+
+    local_urls = re.findall(r'(file:///[^\s]+)', definition)
+    # Remove duplicates, don't upload same files twice.
+    local_urls = list(set(local_urls))
+
+    for local_url in local_urls:
+
+        files = {
+            'path': open(local_url.replace("file://", ""), 'rb'),
+        }
+        post_data = {
+            'token': data["secrets"]["API_KEY"]
+        }
+
+        print >> sys.stdout, "Uploading artifact %s" % local_url
+
+        request = requests.post(
+            urlparse.urljoin(artifacts_url, artifacts_upload_path),
+            files=files,
+            data=post_data)
+
+        if request.status_code != requests.codes.OK:
+            print >> sys.stderr, "File at %s could not be uploaded. Please contact LAVA support team." % local_url
+            continue
+
+        definition = definition.replace(
+            local_url,
+            urlparse.urljoin(artifacts_url, request.text))
+
+    return definition
